======
jsalve
======

JSON API toolkit for Python applications

Requirements
------------

Python 3. Python 2 is **not** supported and there is **no** plan to support it.

Install
-------

Use ``pip``::

    pip install jsalve

Documentation
-------------

You can read the documentation on the **jsalve**
`Read The Docs page <http://jsalve.readthedocs.org/en/latest/>`_.

Contributing
------------

The Github repository is the issue tracker. Please submit issues here. Pull requests are appreciated.

Please follow the Django Community Code of Conduct (https://www.djangoproject.com/conduct/) while
contributing to **jsalve**.

Tests
-----

Use **py.test**. Make sure you have it installed. Clone the **jsalve** repository.
From the repository directory, run::

    py.test tests

